import { ArnFormat, Duration, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnRemediationConfiguration, IRule } from 'aws-cdk-lib/aws-config';
import { IConstruct } from 'constructs';
import { IRemediationTarget } from './lib';
export interface IRemediationConfiguration {
    readonly remediationConfigurationArn: string;
    readonly remediationConfigurationName: string;
}
declare abstract class RemediationConfigurationBase extends Resource implements IRemediationConfiguration {
    abstract readonly remediationConfigurationArn: string;
    abstract readonly remediationConfigurationName: string;
}
export interface RemediationConfigurationAttributes {
    readonly arn?: string;
    readonly name?: string;
}
export interface RemediationConfigurationProps extends ResourceProps {
    readonly automatic?: boolean;
    readonly configRule: IRule;
    readonly maximumAutomaticAttempts?: number;
    readonly resourceParameter?: string;
    readonly resourceType?: string;
    readonly retryInterval?: Duration;
    readonly staticParameters: {
        [key: string]: any[];
    };
    readonly target: IRemediationTarget;
}
export declare class RemediationConfiguration extends RemediationConfigurationBase {
    static readonly ARN_FORMAT: ArnFormat;
    static fromRemediationConfigurationArn(scope: IConstruct, id: string, arn: string): IRemediationConfiguration;
    static fromRemediationConfigurationAttributes(scope: IConstruct, id: string, attrs: RemediationConfigurationAttributes): IRemediationConfiguration;
    static fromRemediationConfigurationName(scope: IConstruct, id: string, name: string): IRemediationConfiguration;
    private readonly _parameters;
    readonly automatic?: boolean;
    readonly configRule: IRule;
    readonly maximumAutomaticAttempts?: number;
    readonly resourceType?: string;
    readonly retryInterval?: Duration;
    readonly resource: CfnRemediationConfiguration;
    readonly remediationConfigurationArn: string;
    readonly remediationConfigurationName: string;
    constructor(scope: IConstruct, id: string, props: RemediationConfigurationProps);
    addParameter(key: string, ...values: string[]): void;
    protected renderParameters(): any;
}
export {};
