import { ArnFormat, IResource, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnStandard } from 'aws-cdk-lib/aws-securityhub';
import { IConstruct } from 'constructs';
export interface RuleSetProps {
    readonly default?: boolean;
    readonly description?: string;
    readonly global?: boolean;
    readonly id: string;
    readonly name?: string;
    readonly version: string;
}
export interface ScopedRuleSet {
    readonly arn: string;
    readonly default?: boolean;
    readonly description?: string;
    readonly id: string;
    readonly name?: string;
    readonly version: string;
}
export declare class RuleSet {
    static readonly ARN_FORMAT: ArnFormat;
    static readonly CIS_FOUNDATIONS_1_2_0: RuleSet;
    static readonly CIS_FOUNDATIONS_1_4_0: RuleSet;
    static readonly FOUNDATIONAL_BEST_PRACTICES_1_0_0: RuleSet;
    static readonly NIST_800_53_5_0_0: RuleSet;
    static readonly PCI_DSS_3_2_1: RuleSet;
    private static of;
    private readonly _props;
    private constructor();
    bind(scope: IConstruct): ScopedRuleSet;
}
export interface IStandard extends IResource {
    readonly standardArn: string;
}
declare abstract class StandardBase extends Resource implements IStandard {
    abstract readonly standardArn: string;
}
export interface StandardProps extends ResourceProps {
    readonly disabledControls?: string[];
    readonly ruleSet: RuleSet;
}
export interface DisableControlOptions {
    readonly reason: string;
}
export declare class Standard extends StandardBase {
    static readonly ARN_FORMAT: ArnFormat;
    static fromStandardArn(scope: IConstruct, id: string, arn: string): IStandard;
    private readonly _disabledControls;
    private readonly _scopedRuleSet;
    readonly resource: CfnStandard;
    readonly standardArn: string;
    constructor(scope: IConstruct, id: string, props: StandardProps);
    disableControl(control: string, options: DisableControlOptions): void;
}
export {};
