import { ArnFormat, IResource, Resource, ResourceProps } from 'aws-cdk-lib';
import { CfnDocument } from 'aws-cdk-lib/aws-ssm';
import { IConstruct } from 'constructs';
import { IDocumentContent } from './lib';
export interface IDocument extends IResource {
    readonly documentArn: string;
    readonly documentName: string;
}
export declare class DocumentType {
    static readonly APPLICATION_CONFIGURATION: DocumentType;
    static readonly APPLICATION_CONFIGURATION_SCHEMA: DocumentType;
    static readonly AUTOMATION: DocumentType;
    static readonly AUTOMATION_CHANGE_TEMPLATE: DocumentType;
    static readonly COMMAND: DocumentType;
    static readonly DEPLOYMENT_STRATEGY: DocumentType;
    static readonly PACKAGE: DocumentType;
    static readonly POLICY: DocumentType;
    static readonly SESSION: DocumentType;
    static of(value: string): DocumentType;
    readonly name: string;
    private constructor();
}
export declare class DocumentUpdateMethod {
    static readonly NEW_VERSION: DocumentUpdateMethod;
    static readonly REPLACE: DocumentUpdateMethod;
    static of(value: string): DocumentUpdateMethod;
    readonly value: string;
    private constructor();
}
export interface DocumentRequirement {
    readonly document: IDocument;
    readonly version?: string;
}
export interface DocumentBaseProps extends ResourceProps {
    readonly content: IDocumentContent;
    readonly documentType?: DocumentType;
    readonly name?: string;
    readonly requires?: DocumentRequirement[];
    readonly targetType?: string;
    readonly updateMethod?: DocumentUpdateMethod;
    readonly versionName?: string;
}
export declare class DocumentBase extends Resource implements IDocument {
    static readonly ARN_FORMAT: ArnFormat;
    private readonly _requires;
    readonly content: IDocumentContent;
    readonly documentType?: DocumentType;
    readonly name?: string;
    readonly targetType?: string;
    readonly updateMethod?: DocumentUpdateMethod;
    readonly versionName?: string;
    get requires(): DocumentRequirement[];
    readonly resource: CfnDocument;
    readonly documentArn: string;
    readonly documentName: string;
    constructor(scope: IConstruct, id: string, props: DocumentBaseProps);
    protected addRequirement(requirement: DocumentRequirement): IDocument;
    protected validate(): string[];
}
