export declare function trimString(input: string, length: number): string;
/**
 * Checks to see if a given object has any keys. If the object has keys then
 * the input object is returned. If the input object is empty then `undefined`
 * is returned instead.
 *
 * @param obj The object to process.
 * @returns The input object or `undefined` if the input object is empty.
 */
export declare function undefinedIfNoKeys<A>(obj: A): A | undefined;
/**
 * Removed undefined elements from an array.
 *
 * @param obj The array to process.
 * @returns A copy of the input array with any `undefined` elements removed.
 */
export declare function definedElements<A>(obj: (A | undefined)[]): A[];
/**
 * Removed undefined alements from an array. If all elements of the array are
 * `undefined` then the result of the entire operation is `undefined`.
 *
 * @param obj The array to process.
 * @returns A copy of the input array with any `undefined` elements removed or
 * `undefined` if the array is empty after processing.
 */
export declare function definedElementsOrUndefined<A>(obj: (A | undefined)[]): A[] | undefined;
/**
 * Creates a copy of an object that has keys with an undefined value removed.
 *
 * @param obj The object to process.
 * @returns A copy of the input object where keys with undefined values are
 * removed.
 */
export declare function definedFields<A>(obj: A): A;
/**
 * Creates a copy of the object that has keys with an undefined value removed.
 * If the resulting objecty has no keys `undefined` is returned instead of an
 * empty object.
 *
 * @param obj The object to process.
 * @returns A copy of the input object where keys with undefined values are
 * removed or `undefined` if the object has no remaining keys after processing.
 */
export declare function definedFieldsOrUndefined<A>(obj: A): A | undefined;
export declare function flatten<A>(obj: A[][]): A[];
export declare function flattenedOrUndefined<A>(obj: A[][]): A[] | undefined;
export declare function includesAll<A>(obj: A[], values: A[]): boolean;
